eprllib.Env.MultiAgent.EnvUtils — eprllib: use EnergyPlus as an environment for DRL control

Skip to main content
`Ctrl`+`K`

# eprllib.Env.MultiAgent.EnvUtils

## Environment Utilities

This module contain the methods used in the environment process.

Functions

`EP_API_add_path`([version, path]) | This method add the EnergyPlus Python API to the system path.
`actuators_to_agents`(agent_config) | Take the ep_actuator dict and transform it to the agent, thermal zone, and actuator type dict.
`continuous_action_space`() | This method construct the action space of the environment.
`discrete_action_space`([n]) | This method construct the action space of the environment.